const _fields = {
  stripe_api_account_id: {
    label: "Stripe API Account ID",
    type: "string",
    render: "select",
    tooltip:
      "The Api account ID that holds Stripe's Api keys as defined in Xuda’s dashboard",
    mandatory: true,
    ajax_call: {
      url: "https://cpi.xuda.io/get_plugin_setup",
      data: { plugin_name: "@xuda.io/xuda-plugin-stripe-core" },
      callback: function (data, field) {
        field.options = _.map(data.accounts, function (val, key) {
          return { label: val.name, value: key };
        });
      },
    },
  },
  widgetCallbackEvent: {
    label: "Callback Event Id",
    type: "string",
    tooltip: "A callback event ID triggered when operation is completed",
  },
  stripe_customer_id: {
    label: "Customer ID",
    type: "string",
    tooltip: "The ID of an existing customer.",
    mandatory: true,
  },
};

export const methods = {
  stripe_credit_card_payout: {
    name: "Credit Card Payout",
    tooltip: "To charge a credit or a debit card with user interface.",
    fields: {
      stripe_api_account_id: _fields.stripe_api_account_id,
      widgetCallbackEvent: _fields.widgetCallbackEvent,
      stripe_customer_id: _fields.stripe_customer_id,
      stripe_amount: {
        label: "Amount",
        type: "number",
        tooltip:
          "Amount intended to be collected by this payment. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).",
        mandatory: true,
      },
      stripe_email: {
        label: "Email",
        type: "string",
        tooltip:
          "The email address to which this charge’s receipt will be sent. The receipt will not be sent until the charge is paid, and no receipts will be sent for test mode charges. If this charge is for a Customer, the email address specified here will override the customer’s email address. If receipt_email is specified for a charge in live mode, a receipt will be sent regardless of your email settings.",
      },
      stripe_description: {
        label: "Description",
        type: "string",
        tooltip:
          "An arbitrary string which you can attach to a Charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the description of the charge(s) that they are describing.",
      },
      stripe_send_invoice: {
        label: "Send Invoice",
        type: "string",
        render: "select",
        tooltip: "",
        options: [
          {
            label: "Yes",
            value: "",
          },
          {
            label: "No",
            value: "N",
          },
        ],
      },
      stripe_capture: {
        label: "Capture",
        type: "string",
        render: "select",
        tooltip:
          "Whether to immediately capture the charge. Defaults to true. When false, the charge issues an authorization (or pre-authorization), and will need to be captured later. Uncaptured charges expire after a set number of days (7 by default). For more information, see the authorizing charges and settling later documentation.",
        options: [
          {
            label: "Yes",
            value: "",
          },
          {
            label: "No",
            value: "N",
          },
        ],
      },
    },
    response: {
      stripe_charge_id: "ch_3LXlf62eZvKYlo2C0OFiZzUq",
      stripe_card_id: "card_19yUNL2eZvKYlo2CNGsN6EWH",
      stripe_charge_status: "succeeded",
      stripe_customer_id: "cus_AJ78ZaALpqgiuZ",
      stripe_charge_obj: "the whole api response object",
    },
  },
  stripe_add_card_interface: {
    ui: true,
    name: "Add Card",
    tooltip:
      "You can store multiple cards on a customer in order to charge the customer later. You can also store multiple debit cards on a recipient in order to transfer to those cards later. If the card’s owner has no default card, then the new card will become the default. However, if the owner already has a default, then it will not change. To change the default, you should update the customer to have a new default card.",
    fields: {
      stripe_api_account_id: _fields.stripe_api_account_id,
      widgetCallbackEvent: _fields.widgetCallbackEvent,
      stripe_customer_id: _fields.stripe_customer_id,
    },
    response: {
      stripe_card_id: "card_19yUNL2eZvKYlo2CNGsN6EWH",
      stripe_card_brand: "Visa",
      stripe_card_last4: "4242",
      stripe_card_exp_month: "8",
      stripe_card_exp_year: "2029",
    },
  },
  stripe_select_card: {
    ui: true,
    name: "Select Card",
    tooltip:
      "You can select a card from a list of the cards belonging to a customer.",
    fields: {
      stripe_api_account_id: _fields.stripe_api_account_id,
      widgetCallbackEvent: _fields.widgetCallbackEvent,
      stripe_customer_id: _fields.stripe_customer_id,
    },
    response: {
      stripe_card_id: "card_19yUNL2eZvKYlo2CNGsN6EWH",
    },
  },
  stripe_list_cards: {
    ui: true,
    name: "List Cards",
    tooltip:
      "You can select a card from a list of the cards belonging to a customer.",
    fields: {
      stripe_api_account_id: _fields.stripe_api_account_id,
      widgetCallbackEvent: _fields.widgetCallbackEvent,
      stripe_customer_id: _fields.stripe_customer_id,
      stripe_limit: {
        label: "Limit",
        type: "number",
        tooltip:
          "A limit on the number of items to be returned. Limit can range between 1 and 100, and the default is 10",
      },
    },
    response: {
      stripe_card_id: "card_19yUNL2eZvKYlo2CNGsN6EWH",
      stripe_card_brand: "Visa",
      stripe_card_last4: "4242",
      stripe_card_exp_month: "8",
      stripe_card_exp_year: "2029",
    },
  },
  stripe_list_charges: {
    ui: true,
    name: "List Charges",
    tooltip:
      "Returns a list of charges you’ve previously created. The charges are returned in sorted order, with the most recent charges appearing first.",
    fields: {
      stripe_api_account_id: _fields.stripe_api_account_id,
      widgetCallbackEvent: _fields.widgetCallbackEvent,
      stripe_customer_id: _fields.stripe_customer_id,
      stripe_limit: {
        label: "Limit",
        type: "number",
        tooltip:
          "A limit on the number of items to be returned. Limit can range between 1 and 100, and the default is 10",
      },
    },
    response: {
      stripe_charge_id: "ch_3LXlf62eZvKYlo2C0OFiZzUq",
      stripe_charge_obj: "the whole api response object",
    },
  },
};

export const style = true;
